---
feature_story: FS_53_81_66_18
feature_title: types and classes
feature_status: DONE
---

*   Type = arg type = indicates format and value space for a single string (arg value).
    An (arg type, arg value) pair is part of `data_envelope` metadata.

*   Class = envelope class = indicates `envelope_payload` schema of one of the `data_envelope`-s.

See also:
*   FS_37_57_36_29: containers, envelopes, payloads.
*   TODO_66_66_75_78: Split `arg` to `prop` concepts.
